@@ -1,8 +1,9 @@
 """TODO: write"""
 from __future__ import annotations
+from typing import TYPE_CHECKING
+
 from pathlib import Path
 import shlex
-from typing import TYPE_CHECKING
 
 import click
 
@@ -65,15 +66,35 @@ class _MessageFormatter:
         def helper(prop):
             return f"{linker.user_str} '{name}' {prop} directory '{target_dir}'"
 
-        if mode == "overwrite":
-            return self._apply_style(f"Replace {helper('in')}", "file", "warn")
-        elif mode == "exists":
-            return self._apply_style(f"Use existing {helper('in')}", "file", "info")
-        elif mode == "new":
-            return self._apply_style(f"Copy {helper('to')}", "file", "info")
-        elif mode == "fail":
-            return self._apply_style(f"Could not import {helper('to')}", "err", "err")
-        return ""
+        match mode:
+            case "overwrite":
+                return self._apply_style(f"Replace {helper('in')}", "file", "warn")
+            case "exists":
+                return self._apply_style(f"Use existing {helper('in')}", "file", "info")
+            case "new":
+                return self._apply_style(f"Copy {helper('to')}", "file", "info")
+            case "fail":
+                return self._apply_style(
+                    f"Could not import {helper('to')}", "err", "err"
+                )
+            case _:
+                raise NotImplementedError
+
+    def show(self, linker: FileLinker, name: str, mode: str):
+        """TODO: write"""
+        match mode:
+            case "diff":
+                return self._apply_style(
+                    f"Diff of {linker.user_str} '{name}' with local version",
+                    "info",
+                    "info",
+                )
+            case "no-diff":
+                return self._apply_style(
+                    f"Contents of {linker.user_str} '{name}'", "info", "info"
+                )
+            case _:
+                raise NotImplementedError
 
     def template_dict(self, target: Path, overwrite: bool = False):
         pref = "file"
